@@ -1,4 +1,4 @@
 from . import errors
 from .application import JSONPRCCollection, JSONPRCApplication
 from .serializers import JSONRPC20Serializer, JSONRPC10Serializer
-from .client import Client
\ No newline at end of file
+from .client import Client, WebClient
\ No newline at end of file
